@@ -1,6 +1,6 @@
 package swat;
 
-our $VERSION = '0.1.74';
+our $VERSION = '0.1.75';
 
 use base 'Exporter'; 
 
@@ -358,7 +358,7 @@ Just write it up to a special file  called `host' and swat will use it.
 
     echo 'app.local' > host
 
-As swat makes http requests with the help of curl, the host name should be complaint with curl requirements, this
+As swat makes http requests with the help of curl, the host name should be compliant with curl requirements, this
 for example means you may define a http schema or port here:
 
     echo 'https://app.local' >> host
@@ -763,6 +763,18 @@ C<match_l> - in TAP output truncate matching strings to {match_l} bytes;  defaul
 
 
 
+=item *
+
+C<swat_purge_cache> - remove swat cache files at the end of test run; default value is `\0' ( do not remove ).
+
+
+
+=item *
+
+C<swat_my> - sets alternative file path for swat.my configuration file; See L<alternative swat ini files locations|#alternative-swat-ini-files-locations> for the explanation of what is swat.my file.
+
+
+
 =back
 
 
